==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/fi_FI.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Vaihe 1 epäonnistui. Poikkeus: %s",
    "Step 2 failed. Exception: %s" : "Vaihe 2 epäonnistui. Poikkeus: %s",
    "External storage" : "Ulkoinen tallennustila",
    "Storage with id \"%i\" not found" : "Tallennustilaa tunnisteella \"%i\" ei löytynyt",
    "Invalid mount point" : "Virheellinen liitoskohta",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Grant access" : "Salli pääsy",
    "Access granted" : "Pääsy sallittu",
    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
    "Generate keys" : "Luo avaimet",
    "Error generating key pair" : "Virhe luotaessa avainparia",
    "Enable encryption" : "Käytä salausta",
    "Enable previews" : "Käytä esikatseluja",
    "Check for changes" : "Tarkista muutokset",
    "Never" : "Ei koskaan",
    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
    "Every time the filesystem is used" : "Aina kun tiedostojärjestelmää käytetään",
    "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
    "(group)" : "(ryhmä)",
    "Saved" : "Tallennettu",
    "Builtin" : "Sisäänrakennettu",
    "None" : "Ei mitään",
    "OAuth1" : "OAuth1",
    "App key" : "Sovellusavain",
    "App secret" : "Sovellussalaisuus",
    "OAuth2" : "OAuth2",
    "Client ID" : "Asiakkaan tunniste",
    "Client secret" : "Asiakassalaisuus",
    "OpenStack" : "OpenStack",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Rackspace" : "Rackspace",
    "API key" : "API-avain",
    "Username and password" : "Käyttäjätunnus ja salasana",
    "RSA public key" : "Julkinen RSA-avain",
    "Public key" : "Julkinen avain",
    "Amazon S3" : "Amazon S3",
    "Port" : "Portti",
    "Region" : "Alue",
    "Enable SSL" : "Käytä SSL:ää",
    "WebDAV" : "WebDAV",
    "URL" : "Verkko-osoite",
    "Remote subfolder" : "Etäalikansio",
    "Secure https://" : "Salattu https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Isäntä",
    "Secure ftps://" : "Salattu ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Paikallinen",
    "Location" : "Sijainti",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Jaa",
    "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista",
    "Username as share" : "Käyttäjänimi jakona",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Palvelun nimi",
    "<b>Note:</b> " : "<b>Huomio:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Huomio:</b> PHP:n cURL-tuki ei ole käytössä tai sitä ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää ottamaan cURL-tuki käyttöön.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Huomio:</b> PHP:n FTP-tuki ei ole käytössä tai sitä ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää ottamaan FTP-tuki käyttöön.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Huomio:</b> \"%s\" ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää asentamaan puuttuva kohde.",
    "No external storage configured" : "Erillistä tallennustilaa ei ole määritetty",
    "You can add external storages in the personal settings" : "Voit lisätä erillisiä tallennustiloja henkilökohtaisista asetuksistasi",
    "Name" : "Nimi",
    "Storage type" : "Tallennustilan tyyppi",
    "External Storage" : "Erillinen tallennusväline",
    "Folder name" : "Kansion nimi",
    "Authentication" : "Tunnistautuminen",
    "Configuration" : "Asetukset",
    "Available for" : "Saatavuus",
    "Advanced settings" : "Lisäasetukset",
    "Delete" : "Poista",
    "Add storage" : "Lisää tallennustila",
    "Enable User External Storage" : "Ota käyttöön ulkopuoliset tallennuspaikat",
    "Allow users to mount the following external storage" : "Salli käyttäjien liittää seuraavat erilliset tallennusvälineet"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files_external/l10n/fi_FI.js <==
OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "Vaihe 1 epäonnistui. Poikkeus: %s",
    "Step 2 failed. Exception: %s" : "Vaihe 2 epäonnistui. Poikkeus: %s",
    "External storage" : "Ulkoinen tallennustila",
    "Storage with id \"%i\" not found" : "Tallennustilaa tunnisteella \"%i\" ei löytynyt",
    "Invalid mount point" : "Virheellinen liitoskohta",
    "%s" : "%s",
    "Personal" : "Henkilökohtainen",
    "System" : "Järjestelmä",
    "Grant access" : "Salli pääsy",
    "Access granted" : "Pääsy sallittu",
    "Error configuring OAuth1" : "Virhe OAuth1:n asetuksia tehdessä",
    "Error configuring OAuth2" : "Virhe OAuth2:n asetuksia tehdessä",
    "Generate keys" : "Luo avaimet",
    "Error generating key pair" : "Virhe luotaessa avainparia",
    "Enable encryption" : "Käytä salausta",
    "Enable previews" : "Käytä esikatseluja",
    "Enable sharing" : "Käytä jakamista",
    "Check for changes" : "Tarkista muutokset",
    "Never" : "Ei koskaan",
    "Once every direct access" : "Kerran aina suoran käytön yhteydessä",
    "All users. Type to select user or group." : "Kaikki käyttäjät. Kirjoita valitaksesi käyttäjän tai ryhmän.",
    "(group)" : "(ryhmä)",
    "Admin defined" : "Ylläpitäjän määrittämä",
    "Saved" : "Tallennettu",
    "Empty response from the server" : "Tyhjä vastaus palvelimelta",
    "Couldn't access. Please logout and login to activate this mount point" : "Käyttö epäonnistui. Kirjaudu ulos ja takaisin sisään aktivoidaksesi tämän liitospisteen",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Tietojen saaminen ownCloud-palvelimelta epäonnistui: {code} {type}",
    "Couldn't get the list of external mount points: {type}" : "Erillisten liitospisteiden listauksen noutaminen epäonnistui: {type}",
    "There was an error with message: " : "Tapahtui virhe viestillä:",
    "External mount error" : "Ulkoinen liitosvirhe",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Windows-verkkoasemien liitospisteiden listauksen noutaminen epäonnistui: tyhjä vastaus palvelimelta",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Jotkin määritetyt erilliset liitospisteet eivät ole yhdistettynä. Napsauta punaisia rivejä saadaksesi lisätietoja",
    "Please enter the credentials for the {mount} mount" : "Anna kirjautumistiedot liitokselle {mount}",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Credentials saved" : "Kirjautumistiedot tallennettu",
    "Credentials saving failed" : "Kirjautumistietojen tallentaminen epäonnistui",
    "Credentials required" : "Kirjautumistiedot vaaditaan",
    "Save" : "Tallenna",
    "Builtin" : "Sisäänrakennettu",
    "None" : "Ei mitään",
    "OAuth1" : "OAuth1",
    "App key" : "Sovellusavain",
    "App secret" : "Sovellussalaisuus",
    "OAuth2" : "OAuth2",
    "Client ID" : "Asiakkaan tunniste",
    "Client secret" : "Asiakassalaisuus",
    "OpenStack" : "OpenStack",
    "Rackspace" : "Rackspace",
    "API key" : "API-avain",
    "Username and password" : "Käyttäjätunnus ja salasana",
    "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
    "RSA public key" : "Julkinen RSA-avain",
    "Public key" : "Julkinen avain",
    "Amazon S3" : "Amazon S3",
    "Port" : "Portti",
    "Region" : "Alue",
    "Enable SSL" : "Käytä SSL:ää",
    "WebDAV" : "WebDAV",
    "URL" : "Verkko-osoite",
    "Remote subfolder" : "Etäalikansio",
    "Secure https://" : "Salattu https://",
    "Dropbox" : "Dropbox",
    "FTP" : "FTP",
    "Host" : "Isäntä",
    "Secure ftps://" : "Salattu ftps://",
    "Google Drive" : "Google Drive",
    "Local" : "Paikallinen",
    "Location" : "Sijainti",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "SFTP with secret key login" : "SFTP salaisen avaimen kirjautumisella",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Jaa",
    "SMB / CIFS using OC login" : "SMB / CIFS käyttäen OC-kirjautumista",
    "Username as share" : "Käyttäjänimi jakona",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Palvelun nimi",
    "Request timeout (seconds)" : "Pyynnön aikakatkaisu (sekunneissa)",
    "<b>Note:</b> " : "<b>Huomio:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Huomio:</b> PHP:n cURL-tuki ei ole käytössä tai sitä ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää ottamaan cURL-tuki käyttöön.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Huomio:</b> PHP:n FTP-tuki ei ole käytössä tai sitä ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää ottamaan FTP-tuki käyttöön.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Huomio:</b> \"%s\" ei ole asennettu. Kohteen %s liittäminen ei ole mahdollista. Pyydä järjestelmän ylläpitäjää asentamaan puuttuva kohde.",
    "No external storage configured" : "Erillistä tallennustilaa ei ole määritetty",
    "You can add external storages in the personal settings" : "Voit lisätä erillisiä tallennustiloja henkilökohtaisista asetuksistasi",
    "Name" : "Nimi",
    "Storage type" : "Tallennustilan tyyppi",
    "External Storage" : "Erillinen tallennusväline",
    "Folder name" : "Kansion nimi",
    "Authentication" : "Tunnistautuminen",
    "Configuration" : "Asetukset",
    "Available for" : "Saatavuus",
    "Add storage" : "Lisää tallennustila",
    "Advanced settings" : "Lisäasetukset",
    "Delete" : "Poista",
    "Allow users to mount external storage" : "Salli käyttäjien liittää erillisiä tallennustiloja",
    "Allow users to mount the following external storage" : "Salli käyttäjien liittää seuraavat erilliset tallennusvälineet"
},
"nplurals=2; plural=(n != 1);");
